@@ -7,6 +7,9 @@ knitr::opts_chunk$set(
 ## ----eval = FALSE--------------------------------------------------------
 #  devtools::install_github("ColinFay/tidystringdist")
 
+## ----eval = FALSE--------------------------------------------------------
+#  install.packages("tidystringdist")
+
 ## ------------------------------------------------------------------------
 library(tidystringdist)
 
@@ -22,18 +25,20 @@ tidy_comb("Paris", state.name[1:3])
 library(dplyr)
 data(starwars)
 tidy_comb_sw <- tidy_comb_all(starwars, name)
-tidy_stringdist(tidy_comb_sw, method = "jw")
+tidy_stringdist(tidy_comb_sw)
+
+## ------------------------------------------------------------------------
+tidy_stringdist(tidy_comb_sw, method = c("osa","jw"))
 
 ## ------------------------------------------------------------------------
 tidy_stringdist(tidy_comb_sw, method= "osa") %>%
-  filter(string_dist > 20) %>%
-  arrange(desc(string_dist))
+  filter(osa > 20) %>%
+  arrange(desc(osa))
 
 ## ------------------------------------------------------------------------
 starwars %>%
   filter(species == "Droid") %>%
   tidy_comb_all(name) %>%
   tidy_stringdist() %>% 
-  filter(string_dist > 2) %>%
-  arrange(desc(string_dist))
+  summarise_if(is.numeric, mean)
 
