@@ -11,5 +11,12 @@ test_that("tidy stringdist works", {
   expect_true(inherits(df, "tbl_df"))
   expect_true(inherits(df, "tbl"))
   expect_true(inherits(df, "data.frame"))
-  expect_false(any(df$string_dist > 1))
+  expect_false(any(df$jw > 1))
+  df <- tidy_stringdist(tidy_comb_sw)
+  expect_equal(nrow(tidy_comb_sw), nrow(df))
+  expect_equal(ncol(df), 12)
+  expect_true(inherits(df, "tbl_df"))
+  expect_true(inherits(df, "tbl"))
+  expect_true(inherits(df, "data.frame"))
+  expect_false(any(df$jw > 1))
 })
